/*
 *  simple.c -- implements the yes/no, message and info box
 *
 *  Originally by Savio Lam (lam836@cs.cuhk.hk)
 *  Completely reworked by Alessandro Rubini (rubini@ipvvis.unipv.it).
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "dialog.h"
#include "dialogInt.h"

/*
 * Display a dialog box with zero, one or two buttons (or custom ones).
 */
int
dialog_simple (struct Dialog_desc *desc)
{
    int key, button = desc->selected;
    WINDOW *dialog;
    struct Dialog_butt *bptr; int i;

    /* yesno and msg use one hline, info none of them */
    desc->hlinenum = desc->type==DIALOG_INFO ? 0 : 1;
    desc->hline[0] = -3;

    /* The caller can build the buttons beforehand, othwise, default applies */
    if (!desc->buttons) {
	switch(desc->type) {
	  case DIALOG_YESNO: dialog_defaultbuttons(desc," Yes :  No  "); break;
	  case DIALOG_MSG:   dialog_defaultbuttons(desc,"  OK  "); break;
	  case DIALOG_INFO: break;
	  default:          return DIALOG_ERROR;
	}
    }

    _dialog_setup(desc);

    dialog = desc->win;
    wrefresh (dialog);

    if (desc->type==DIALOG_INFO) {
	delwin(dialog);
	return 0;
    }

    while ( (key=_dialog_wgetch(dialog)) != DIALOG_ESC) {
	if (key < 0x100) key=tolower(key);

	/* first of all, look for an hotkey */
	for (i=0, bptr=desc->buttons; i<desc->buttnum; i++, bptr++) {
	    if ( key==(int)tolower(*bptr->hotkey) ||
		 key==DIALOG_M_EVENT+(int)toupper(*bptr->hotkey) ) {
		delwin(dialog);
		return(i);
	    }
	    if (key == DIALOG_M_EVENT+(int)tolower(*bptr->hotkey)) {
		button = i;
		break;
	    }
	}

	/* otherwise, use the old switch */
	switch (key) {

	case DIALOG_TAB:
	case KEY_DOWN:   /* increment */
	case KEY_RIGHT:
	    button++; button %=  desc->buttnum; break;
	    
	case KEY_UP:
	case KEY_LEFT:   /* decrement */
	    button--; if (button<0) button=desc->buttnum-1; break;

	case ' ':
	case '\n':
	    delwin (dialog);
	    return button;
	}
	/* refresh only if needed */
	if (desc->buttons[button].status==DIALOG_B_DISABLED) {
	    desc->buttons[button].status=DIALOG_B_ENABLED;
	    _dialog_print_buttons(desc);
	    wrefresh (dialog);
	}
    }

    delwin (dialog);
    return -1;			/* ESC pressed */
}



/**** Local Variables:  ****/
/**** tab-width:8       ****/
/**** c-indent-level:4  ****/
/**** c-label-offset:-2 ****/
/**** End:              ****/
